Module math

Module math 

Mathematical functions.

This module provides math functions for JMESPath queries.

For complete function reference with signatures and examples, see the functions module documentation or use jpx --list-category math.

Example

use jmespath::{Runtime, Variable};
use jmespath_extensions::math;

let mut runtime = Runtime::new();
runtime.register_builtin_functions();
math::register(&mut runtime);

Structs

AbsFn
AcosFn
AddFn
AsinFn
Atan2Fn
AtanFn
CeilFn
ClampFn
CorrelationFn
CosFn
CovarianceFn
CumulativeSumFn
DegToRadFn
DivideFn
EwmaFn
FloorFn
FormatNumberFn
HistogramFn
LogFn
MedianFn
ModFn
ModeFn
MovingAvgFn
MultiplyFn
NormalizeFn
OutliersIqrFn
OutliersZscoreFn
PercentileFn
PowFn
QuantileFn
QuartilesFn
RadToDegFn
RateOfChangeFn
RoundFn
SignFn
SinFn
SqrtFn
StandardizeFn
StddevFn
SubtractFn
TanFn
ToFixedFn
TrendFn
TrendSlopeFn
VarianceFn
ZScoreFn

Functions

register
Register all math functions with the runtime.
register_filtered
Register only the math functions that are in the enabled set.